About
=====

Contributors
------------

Core Development Team:

* `James A. R. Marshall`_ (james.marshall@sheffield.ac.uk)
* `Andreagiovanni Reina`_
* `Thomas Bose`_

Contributors: 

* Robert Dennison

Packaging, Documentation and Deployment:

* `Will Furnass`_

Windows Compatibility:

* `Renato Pagliara Vasquez`_

Citation
--------

If you use MuMoT in your own work please cite the original paper describing MuMoT, as well as the DOI for the version of MuMoT you used (to credit developers involved in that version):

* Marshall, J. A. R., Reina, A., Bose, T. (2019) Multiscale Modelling Tool: Mathematical modelling of collective behaviour without the maths. PLoS one **14**(9): e0222906. `doi:10.1371/journal.pone.0222906 <https://doi.org/10.1371/journal.pone.0222906>`__
* Marshall, J. A. R., Reina, A., Bose, T., Dennison, R., Furnass, W., Pagliara Vasquez, R. (2020) MuMoT release 1.2.1 `10.15131/shef.data.12403118 <https://doi.org/10.15131/shef.data.12403118>`__
* Marshall, J. A. R., Reina, A., Bose, T., Dennison, R., Furnass, W., Pagliara Vasquez, R. (2019) MuMoT release 1.1.2 `doi:10.15131/shef.data.9925010 <https://doi.org/10.15131/shef.data.9925010>`__
* Marshall, J. A. R., Reina, A., Bose, T. (2019) MuMoT release 1.0.0 `doi:10.15131/shef.data.7951298.v1 <https://doi.org/10.15131/shef.data.7951298.v1>`__

.. todo:: Add formatted citation and BibTeX entry inc ORDA_ (FigShare) / Zenodo_ DOI.

Acknowledgments
---------------

Funding
^^^^^^^

MuMoT was developed with funds from the `European Research Council`_ (ERC) 
under the European Union's `Horizon 2020`_ research and innovation programme 
(grant agreement number 647704 - DiODe_), and from Corporate Information
and Computing Services, University of Sheffield.

Included third-party code
^^^^^^^^^^^^^^^^^^^^^^^^^

* ``mumot/__init__.py``: contains functions (C) 2012 Free Software Foundation, under the MIT Licence

mybinder.org
^^^^^^^^^^^^

The MuMoT manual is :ref:`runnable online <getting_started>` via the the excellent and free `mybinder.org <https://mybinder.org/>`__ service,
funded by the `Gordon and Betty Moore Foundation <https://www.moore.org/>`__.

.. _Andreagiovanni Reina: https://areina.staff.shef.ac.uk/
.. _DiODe: http://diode.group.shef.ac.uk/
.. _European Research Council: lhttps://erc.europa.eu/>`__ 
.. _Horizon 2020: https://ec.europa.eu/programmes/horizon2020/en/
.. _James A. R. Marshall: https://staffwww.dcs.shef.ac.uk/people/J.Marshall/james.html
.. _ORDA: https://orda.shef.ac.uk/ 
.. _Renato Pagliara Vasquez: https://mae.princeton.edu/people/graduate-students/vasquez
.. _Thomas Bose: http://thomas-bose.staff.shef.ac.uk/
.. _Will Furnass: https://learningpatterns.me/
.. _Zenodo: https://zenodo.org/
